
#!perl

# This file was automatically generated by Dist::Zilla::Plugin::Bencher::Scenario.

use Test::More;

eval "use Bencher 0.19";
plan skip_all => "Bencher 0.19 required to run benchmark" if $@;
plan skip_all => "EXTENDED_TESTING not turned on" unless $ENV{EXTENDED_TESTING};

diag explain Bencher::bencher(action=>'bench', scenario_module=>'Allocations');
ok 1;

done_testing();
